==> openshift-model-6.0.0-sources.jar: io/fabric8/openshift/api/model/ServiceAccountRestrictionFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ServiceAccountRestrictionFluent<A extends ServiceAccountRestrictionFluent<A>> extends Fluent<A>{
  public A addToNamespaces(Integer index,String item);
  public A setToNamespaces(Integer index,String item);
  public A addToNamespaces(java.lang.String... items);
  public A addAllToNamespaces(Collection<String> items);
  public A removeFromNamespaces(java.lang.String... items);
  public A removeAllFromNamespaces(Collection<String> items);
  public List<String> getNamespaces();
  public String getNamespace(Integer index);
  public String getFirstNamespace();
  public String getLastNamespace();
  public String getMatchingNamespace(Predicate<String> predicate);
  public Boolean hasMatchingNamespace(Predicate<String> predicate);
  public A withNamespaces(List<String> namespaces);
  public A withNamespaces(java.lang.String... namespaces);
  public Boolean hasNamespaces();
  public A addToServiceaccounts(Integer index,ServiceAccountReference item);
  public A setToServiceaccounts(Integer index,ServiceAccountReference item);
  public A addToServiceaccounts(io.fabric8.openshift.api.model.ServiceAccountReference... items);
  public A addAllToServiceaccounts(Collection<ServiceAccountReference> items);
  public A removeFromServiceaccounts(io.fabric8.openshift.api.model.ServiceAccountReference... items);
  public A removeAllFromServiceaccounts(Collection<ServiceAccountReference> items);
  public A removeMatchingFromServiceaccounts(Predicate<ServiceAccountReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildServiceaccounts instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServiceAccountReference> getServiceaccounts();
  public List<ServiceAccountReference> buildServiceaccounts();
  public ServiceAccountReference buildServiceaccount(Integer index);
  public ServiceAccountReference buildFirstServiceaccount();
  public ServiceAccountReference buildLastServiceaccount();
  public ServiceAccountReference buildMatchingServiceaccount(Predicate<ServiceAccountReferenceBuilder> predicate);
  public Boolean hasMatchingServiceaccount(Predicate<ServiceAccountReferenceBuilder> predicate);
  public A withServiceaccounts(List<ServiceAccountReference> serviceaccounts);
  public A withServiceaccounts(io.fabric8.openshift.api.model.ServiceAccountReference... serviceaccounts);
  public Boolean hasServiceaccounts();
  public A addNewServiceaccount(String name,String namespace);
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> addNewServiceaccount();
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> addNewServiceaccountLike(ServiceAccountReference item);
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> setNewServiceaccountLike(Integer index,ServiceAccountReference item);
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> editServiceaccount(Integer index);
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> editFirstServiceaccount();
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> editLastServiceaccount();
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> editMatchingServiceaccount(Predicate<ServiceAccountReferenceBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ServiceaccountsNested<N> extends Nested<N>,ServiceAccountReferenceFluent<ServiceAccountRestrictionFluent.ServiceaccountsNested<N>>{
    public N and();
    public N endServiceaccount();
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/ServiceAccountRestrictionFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ServiceAccountRestrictionFluent<A extends ServiceAccountRestrictionFluent<A>> extends Fluent<A>{
  public A addToNamespaces(int index,String item);
  public A setToNamespaces(int index,String item);
  public A addToNamespaces(java.lang.String... items);
  public A addAllToNamespaces(Collection<String> items);
  public A removeFromNamespaces(java.lang.String... items);
  public A removeAllFromNamespaces(Collection<String> items);
  public List<String> getNamespaces();
  public String getNamespace(int index);
  public String getFirstNamespace();
  public String getLastNamespace();
  public String getMatchingNamespace(Predicate<String> predicate);
  public Boolean hasMatchingNamespace(Predicate<String> predicate);
  public A withNamespaces(List<String> namespaces);
  public A withNamespaces(java.lang.String... namespaces);
  public Boolean hasNamespaces();
  public A addToServiceaccounts(int index,ServiceAccountReference item);
  public A setToServiceaccounts(int index,ServiceAccountReference item);
  public A addToServiceaccounts(io.fabric8.openshift.api.model.ServiceAccountReference... items);
  public A addAllToServiceaccounts(Collection<ServiceAccountReference> items);
  public A removeFromServiceaccounts(io.fabric8.openshift.api.model.ServiceAccountReference... items);
  public A removeAllFromServiceaccounts(Collection<ServiceAccountReference> items);
  public A removeMatchingFromServiceaccounts(Predicate<ServiceAccountReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildServiceaccounts instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServiceAccountReference> getServiceaccounts();
  public List<ServiceAccountReference> buildServiceaccounts();
  public ServiceAccountReference buildServiceaccount(int index);
  public ServiceAccountReference buildFirstServiceaccount();
  public ServiceAccountReference buildLastServiceaccount();
  public ServiceAccountReference buildMatchingServiceaccount(Predicate<ServiceAccountReferenceBuilder> predicate);
  public Boolean hasMatchingServiceaccount(Predicate<ServiceAccountReferenceBuilder> predicate);
  public A withServiceaccounts(List<ServiceAccountReference> serviceaccounts);
  public A withServiceaccounts(io.fabric8.openshift.api.model.ServiceAccountReference... serviceaccounts);
  public Boolean hasServiceaccounts();
  public A addNewServiceaccount(String name,String namespace);
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> addNewServiceaccount();
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> addNewServiceaccountLike(ServiceAccountReference item);
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> setNewServiceaccountLike(int index,ServiceAccountReference item);
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> editServiceaccount(int index);
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> editFirstServiceaccount();
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> editLastServiceaccount();
  public ServiceAccountRestrictionFluent.ServiceaccountsNested<A> editMatchingServiceaccount(Predicate<ServiceAccountReferenceBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ServiceaccountsNested<N> extends Nested<N>,ServiceAccountReferenceFluent<ServiceAccountRestrictionFluent.ServiceaccountsNested<N>>{
    public N and();
    public N endServiceaccount();
    
  }
  
}
